``flask_admin.contrib.fileadmin``
=================================

.. automodule:: flask_admin.contrib.fileadmin

    .. autoclass:: FileAdmin
        :members:
        :exclude-members: can_upload, can_delete, can_delete_dirs, can_mkdir, can_rename,
                          allowed_extensions, list_template, upload_template, mkdir_template,
                          rename_template, editable_extensions, edit_templat

        .. autoattribute:: can_upload
        .. autoattribute:: can_delete
        .. autoattribute:: can_delete_dirs
        .. autoattribute:: can_mkdir
        .. autoattribute:: can_rename
        .. autoattribute:: allowed_extensions
        .. autoattribute:: editable_extensions
        .. autoattribute:: list_template
        .. autoattribute:: upload_template
        .. autoattribute:: mkdir_template
        .. autoattribute:: rename_template
        .. autoattribute:: edit_template
